@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.121';
+our $VERSION = '0.122';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1680,8 +1680,14 @@ sub _set_operational_status {
 
 # All Iridium Classic satellites.
 #
-# Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Mon Apr 29 12:50:43 2019 GMT
+# Generated by Astro::SpaceTrack
+# $ tools/all_iridium_classic -iridium -indent=0
+# on Fri May 17 18:12:28 2019 GMT
+#
+# The following static method is UNSUPPORTED, and exists solely for the
+# benefit of xt/author/iridium_status.t. It may be modified or revoked
+# at any time.
+sub __iridium_status_as_of { return( qw{ 46 5 10 16 4 2019 } ) }
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1703,7 +1709,7 @@ __PACKAGE__->status( add => 24872, iridium => 'D', 'Iridium 18', 'Decayed 2018-0
 __PACKAGE__->status( add => 24873, iridium => '-', 'Iridium 921', 'Tumbling' );
 __PACKAGE__->status( add => 24903, iridium => '-', 'Iridium 26', 'Tumbling' );
 __PACKAGE__->status( add => 24904, iridium => 'D', 'Iridium 25', 'Decayed 2018-05-14' );
-__PACKAGE__->status( add => 24905, iridium => '-', 'Iridium 46', 'Tumbling' );
+__PACKAGE__->status( add => 24905, iridium => 'D', 'Iridium 46', 'Decayed 2019-05-11' );
 __PACKAGE__->status( add => 24906, iridium => 'D', 'Iridium 23', 'Decayed 2018-03-28' );
 __PACKAGE__->status( add => 24907, iridium => '-', 'Iridium 22', 'Tumbling' );
 __PACKAGE__->status( add => 24925, iridium => '-', 'Dummy mass 1', 'Tumbling' );
@@ -1734,7 +1740,7 @@ __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-0
 __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-02-13' );
 __PACKAGE__->status( add => 25169, iridium => 'D', 'Iridium 52', 'Decayed 2018-11-05' );
 __PACKAGE__->status( add => 25170, iridium => 'D', 'Iridium 56', 'Decayed 2018-10-11' );
-__PACKAGE__->status( add => 25171, iridium => '-', 'Iridium 54', 'Tumbling' );
+__PACKAGE__->status( add => 25171, iridium => 'D', 'Iridium 54', 'Decayed 2019-05-11' );
 __PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
 __PACKAGE__->status( add => 25173, iridium => 'D', 'Iridium 53', 'Decayed 2018-09-30' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
@@ -1785,8 +1791,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 # Summary:
 # Operational [+]: 0
 #       Spare [S]: 2
-#    Tumbling [-]: 34
-#     Decayed [D]: 61
+#    Tumbling [-]: 32
+#     Decayed [D]: 63
 
 1;
 
